.. _metadata:

***************************************************
Base classes representing Saml2.0 MetaData elements
***************************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: MetaData
   :synopsis: Base classes representing Saml2.0 metadata elements.
   
Module
==========

.. automodule:: saml2.metadata
   :members: 

